@@ -4,37 +4,37 @@
 #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!#
 #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!#
 #
-# This software was authored by Zhian N. Kamvar and Javier F. Tabima, graduate 
+# This software was authored by Zhian N. Kamvar and Javier F. Tabima, graduate
 # students at Oregon State University; Jonah C. Brooks, undergraduate student at
 # Oregon State University; and Dr. Nik Grünwald, an employee of USDA-ARS.
 #
 # Permission to use, copy, modify, and distribute this software and its
-# documentation for educational, research and non-profit purposes, without fee, 
+# documentation for educational, research and non-profit purposes, without fee,
 # and without a written agreement is hereby granted, provided that the statement
 # above is incorporated into the material, giving appropriate attribution to the
 # authors.
 #
 # Permission to incorporate this software into commercial products may be
-# obtained by contacting USDA ARS and OREGON STATE UNIVERSITY Office for 
+# obtained by contacting USDA ARS and OREGON STATE UNIVERSITY Office for
 # Commercialization and Corporate Development.
 #
 # The software program and documentation are supplied "as is", without any
-# accompanying services from the USDA or the University. USDA ARS or the 
-# University do not warrant that the operation of the program will be 
-# uninterrupted or error-free. The end-user understands that the program was 
-# developed for research purposes and is advised not to rely exclusively on the 
+# accompanying services from the USDA or the University. USDA ARS or the
+# University do not warrant that the operation of the program will be
+# uninterrupted or error-free. The end-user understands that the program was
+# developed for research purposes and is advised not to rely exclusively on the
 # program for any reason.
 #
-# IN NO EVENT SHALL USDA ARS OR OREGON STATE UNIVERSITY BE LIABLE TO ANY PARTY 
+# IN NO EVENT SHALL USDA ARS OR OREGON STATE UNIVERSITY BE LIABLE TO ANY PARTY
 # FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES, INCLUDING
-# LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, 
-# EVEN IF THE OREGON STATE UNIVERSITY HAS BEEN ADVISED OF THE POSSIBILITY OF 
-# SUCH DAMAGE. USDA ARS OR OREGON STATE UNIVERSITY SPECIFICALLY DISCLAIMS ANY 
-# WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
-# MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE AND ANY STATUTORY 
+# LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION,
+# EVEN IF THE OREGON STATE UNIVERSITY HAS BEEN ADVISED OF THE POSSIBILITY OF
+# SUCH DAMAGE. USDA ARS OR OREGON STATE UNIVERSITY SPECIFICALLY DISCLAIMS ANY
+# WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
+# MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE AND ANY STATUTORY
 # WARRANTY OF NON-INFRINGEMENT. THE SOFTWARE PROVIDED HEREUNDER IS ON AN "AS IS"
 # BASIS, AND USDA ARS AND OREGON STATE UNIVERSITY HAVE NO OBLIGATIONS TO PROVIDE
-# MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS. 
+# MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
 #
 #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!#
 #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!#
@@ -44,7 +44,7 @@
 
 .onAttach <- function(...) {
   poppr_vers <- utils::packageVersion("poppr")
-  if (length(unlist(poppr_vers)) > 3){
+  if (length(unlist(poppr_vers)) > 3) {
     appendix <- "\n\nThis version of poppr is under development.\nIf you find any bugs, please report them at https://github.com/grunwaldlab/poppr/issues"
   } else {
     appendix <- ""
@@ -52,32 +52,41 @@
   startupmsg <- paste("This is poppr version", poppr_vers)
   startupmsg <- paste0(startupmsg, ". To get started, type package?poppr")
   paralltype <- ifelse(poppr::poppr_has_parallel(), "available", "unavailable")
-  startupmsg <- paste0(startupmsg, "\nOMP parallel support: ", paralltype, appendix)
+  startupmsg <- paste0(
+    startupmsg,
+    "\nOMP parallel support: ",
+    paralltype,
+    appendix
+  )
   packageStartupMessage(startupmsg)
-  if (!interactive()) return()
+  if (!interactive()) {
+    return()
+  }
 
-  msec <- floor(as.POSIXlt(Sys.time())$sec*1000)
-  if (msec %% 10 > 0) return()
+  msec <- floor(as.POSIXlt(Sys.time())$sec * 1000)
+  if (msec %% 10 > 0) {
+    return()
+  }
 
   tips <- c(
     "\nNeed help? Try the poppr mailing list: http://groups.google.com/d/forum/poppr.\n",
     "\nUse suppressPackageStartupMessages(library(\"poppr\")) to eliminate package startup messages.\n"
   )
-  msec <- floor(as.POSIXlt(Sys.time())$sec*1000)
+  msec <- floor(as.POSIXlt(Sys.time())$sec * 1000)
   packageStartupMessage(tips[1 + (msec %% length(n))])
 }
 
-.onLoad <- function(...){
+.onLoad <- function(...) {
   op <- options()
   op.poppr <- list(
-    poppr.debug = FALSE,     # flag for verbosity
+    poppr.debug = FALSE, # flag for verbosity
     old.bruvo.model = FALSE, # flag for using the old model of Bruvo's distance.
-    poppr.old.dplyr = FALSE  # flag to for testing old version of dplyr
+    poppr.old.dplyr = FALSE # flag to for testing old version of dplyr
   )
   toset <- !(names(op.poppr) %in% names(op))
-  if(any(toset)) options(op.poppr[toset])
+  if (any(toset)) options(op.poppr[toset])
 }
 
-.onUnload <- function (libpath) {
+.onUnload <- function(libpath) {
   library.dynam.unload("poppr", libpath)
 }
