@@ -4,7 +4,7 @@ data("Pinf", package = "poppr")
 
 test_that("Private alleles can be calculated for hierarchies", {
   by_continent <- private_alleles(Pinf, all ~ Continent)
-  by_country   <- private_alleles(Pinf, all ~ Country)
+  by_country <- private_alleles(Pinf, all ~ Country)
   expect_true(nrow(by_continent) <= nPop(setPop(Pinf, ~Continent)))
   expect_true(nrow(by_country) <= nPop(setPop(Pinf, ~Country)))
 })
@@ -17,19 +17,22 @@ test_that("Private alleles can be tabluated over loci", {
 })
 
 test_that("Private alleles can be tabulated over individuals", {
-	skip_on_cran()
-	res <- private_alleles(Pinf, level = "indiv")
-	expect_is(res, "matrix")
+  skip_on_cran()
+  res <- private_alleles(Pinf, level = "indiv")
+  expect_is(res, "matrix")
 })
 
 test_that("Private alleles can handle genpop objects", {
-	skip_on_cran()
-	pinfpop <- genind2genpop(Pinf, quiet = TRUE)
-	expect_is(private_alleles(pinfpop), "matrix")
+  skip_on_cran()
+  pinfpop <- genind2genpop(Pinf, quiet = TRUE)
+  expect_is(private_alleles(pinfpop), "matrix")
 })
 
 test_that("Private alleles throws appropriate errors", {
-	skip_on_cran()
-	expect_error(private_alleles(Pinf, LOCUS ~ .), "Left hand side of LOCUS \\~ \\.")
-	expect_error(private_alleles(Pinf, locus ~ people), "strata:.+?people")
-})
\ No newline at end of file
+  skip_on_cran()
+  expect_error(
+    private_alleles(Pinf, LOCUS ~ .),
+    "Left hand side of LOCUS \\~ \\."
+  )
+  expect_error(private_alleles(Pinf, locus ~ people), "strata:.+?people")
+})
